#
# spec file for package ceres-solver
#
# Copyright (c) 2017-2018 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define sover 1

Name:           ceres-solver
Version:	1.14.0
Release:        bp154.1.22
License:	BSD-3-Clause
Summary:	C++ library for modeling and solving optimization problems
URL:		http://ceres-solver.org/
Group:		Development/Libraries/C and C++
Source:		http://ceres-solver.org/%{name}-%{version}.tar.gz
BuildRequires:	cmake >= 2.8.0
BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(eigen3) >= 3.1.0
BuildRequires:	glog-devel >= 0.3.1
BuildRequires:	suitesparse-devel
BuildRequires:	libcxsparse3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ceres Solver is a C++ library for modeling and solving large,
complicated optimization problems. It can be used to solve Non-linear Least
Squares problems with bounds constraints and general unconstrained optimization
problems.

This package is built with Eigen only.

%package -n libceres-devel
Summary:	Ceres Solver header files
Group:		Development/Libraries/C and C++
Requires:	libceres%{sover} = %{version}

%description -n libceres-devel
Ceres Solver is a C++ library for modeling and solving large,
complicated optimization problems. It can be used to solve Non-linear Least
Squares problems with bounds constraints and general unconstrained optimization
problems.

This package is built with Eigen only.


%package -n libceres%{sover}
Summary:	Ceres Solver shared library
Group:          System/Libraries
License:	LGPL-2.1

%description -n libceres%{sover}
Ceres Solver is a C++ library for modeling and solving large,
complicated optimization problems. It can be used to solve Non-linear Least
Squares problems with bounds constraints and general unconstrained optimization
problems.

This package is built with Eigen only.


%prep
%setup -q

%build
%cmake -DCXSPARSE=ON -DSUITESPARSE=ON -DEIGENSPARSE=ON -DOPENMP=ON -DCXX11=ON -DCMAKE_INSTALL_PREFIX=/usr -DEIGEN_INCLUDE_DIR_HINTS=/usr/include/eigen3 -DGFLAGS=OFF -DMINIGLOG=OFF -DBUILD_SHARED_LIBS=ON
make

%install
%cmake_install

%post -n libceres%{sover} -p /sbin/ldconfig

%postun -n libceres%{sover} -p /sbin/ldconfig

%files -n libceres-devel
%defattr(-,root,root)
%{_includedir}/ceres/
%{_libdir}/cmake/Ceres/
%{_libdir}/libceres.so

%files -n libceres%{sover}
%defattr(-,root,root)
%{_libdir}/libceres.so.*
%changelog
* Tue Jan  1 2019 Jan Engelhardt <jengelh@inai.de>
- Rename %%soname to %%sover to better reflect its use.
- Trim filler wording from description.
* Fri Jun 29 2018 herbert@graeber-clan.de
- Use a _service file for download and compression
- Update to version 1.14.0
  * New EvaluationCallback API. (Keir Mierle)
  * TBB based threading (Yury Prokazov & Mike Vitus)
  * C++11 threads based threading (Mike Vitus)
  * A ceres::Context object to cache and keep track of global state.
    (Mike Vitus)
  * TinySolver - A small dense solver meant for solving small problems
    really fast. [EXPERIMENTAL] (Keir Mierle & Sameer Agarwal)
  * Bazel Build. (Keir Mierle & Rodrigo Queiro)
  * Several other moinor fixes and changes
- Update to version 1.13.0
  * LineSearchMinimizer and GradientProblemSolver are up to 2x faster
    due to fewer function evaluations. (Sameer Agarwal)
  * SPARSE_NORMAL_CHOLESKY is significantly faster because Ceres now
    computes the normal equations exploiting the static block sparsity
    structure. (Cheng Wang & Sameer Agarwal)
  * Add compound with scalar operators for Jets. (Alex Stewart)
  * Enable support for AVX instructions for Jets. (Alex Stewart)
  * Several other moinor fixes and changes
* Sat Mar 25 2017 herbert@graeber-clan.de
- Initial package (Eigen-only)
